@@ -6,7 +6,6 @@ import (
 	"runtime"
 	"strconv"
 
-	"github.com/lmorg/murex/debug"
 	"github.com/lmorg/murex/lang"
 	"github.com/lmorg/murex/lang/types"
 	"github.com/lmorg/murex/shell/autocomplete"
@@ -19,7 +18,6 @@ import (
 )
 
 func init() {
-	lang.DefineMethod("debug", cmdDebug, types.Any, types.Json)
 	lang.DefineFunction("exitnum", cmdExitNum, types.Integer)
 	lang.DefineFunction("bexists", cmdBuiltinExists, types.Json)
 	lang.DefineFunction("cd", cmdCd, types.Null)
@@ -30,57 +28,6 @@ func init() {
 	lang.DefineFunction("man-summary", cmdManSummary, types.Null)
 }
 
-func cmdDebug(p *lang.Process) error {
-	if p.IsMethod {
-		return cmdDebugMethod(p)
-	}
-
-	p.Stdout.SetDataType(types.Boolean)
-
-	v, err := p.Parameters.Bool(0)
-
-	if err != nil {
-		_, err = p.Stdout.Write([]byte(fmt.Sprint(debug.Enabled)))
-		return err
-	}
-	debug.Enabled = v
-	if !v {
-		p.Stdout.Writeln(types.FalseByte)
-		p.ExitNum = 1
-		return nil
-	}
-
-	_, err = p.Stdout.Writeln(types.TrueByte)
-	return err
-}
-
-func cmdDebugMethod(p *lang.Process) error {
-	dt := p.Stdin.GetDataType()
-	p.Stdout.SetDataType(types.Json)
-
-	var (
-		j = make(map[string]interface{})
-		b []byte
-	)
-
-	obj, err := lang.UnmarshalData(p, dt)
-
-	j["Process"] = p.Previous.Dump()
-	j["Data-Type"] = map[string]string{
-		"Murex":             dt,
-		"Go":                fmt.Sprintf("%T", obj),
-		"UnmarshalData Err": fmt.Sprint(err),
-	}
-
-	b, err = json.Marshal(j, p.Stdout.IsTTY())
-	if err != nil {
-		return err
-	}
-
-	_, err = p.Stdout.Writeln(b)
-	return err
-}
-
 func cmdExitNum(p *lang.Process) error {
 	p.Stdout.SetDataType(types.Integer)
 	p.Stdout.Writeln([]byte(strconv.Itoa(p.Previous.ExitNum)))
