@@ -153,7 +153,7 @@ func (tree *ParserT) parseSwitch() (int, error) {
 			prev := tree.prevChar()
 			if prev == ' ' || prev == '\t' {
 				// quotes
-				value, err := tree.parseParen(true)
+				value, err := tree.parseParenthesis(true)
 				if err != nil {
 					return 0, err
 				}
@@ -178,7 +178,7 @@ func (tree *ParserT) parseSwitch() (int, error) {
 				}
 			case '(':
 				tree.charPos++
-				value, err := tree.parseParen(true)
+				value, err := tree.parseParenthesis(true)
 				if err != nil {
 					return 0, err
 				}
@@ -212,11 +212,15 @@ func (tree *ParserT) parseSwitch() (int, error) {
 			switch {
 			case tree.nextChar() == '{':
 				// subshell
-				_, v, _, err := tree.parseSubShell(true, r, varAsString)
+				_, fn, err := tree.parseSubShell(true, r, varAsString)
 				if err != nil {
 					return 0, err
 				}
-				appendToParam(tree, []rune(v.(string))...)
+				val, err := fn()
+				if err != nil {
+					return 0, err
+				}
+				appendToParam(tree, []rune(val.Value.(string))...)
 				tree.statement.canHaveZeroLenStr = true
 			case isBareChar(tree.nextChar()):
 				// start scalar
@@ -240,11 +244,15 @@ func (tree *ParserT) parseSwitch() (int, error) {
 				if err := tree.nextParameter(); err != nil {
 					return 0, err
 				}
-				value, v, _, err := tree.parseSubShell(true, r, varAsString)
+				value, fn, err := tree.parseSubShell(true, r, varAsString)
 				if err != nil {
 					return 0, err
 				}
-				processStatementArrays(tree, value, v, true)
+				val, err := fn()
+				if err != nil {
+					return 0, err
+				}
+				processStatementArrays(tree, value, val.Value, true)
 			case isBareChar(tree.nextChar()):
 				// start scalar
 				if err := tree.nextParameter(); err != nil {
