@@ -22,43 +22,43 @@ func TestFormatTitle(t *testing.T) {
 		},
 		{
 			Title:  "1",
-			Format: []byte{27, ']', '2', ';', '1', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', 27, '\\'},
 		},
 		{
 			Title:  "12",
-			Format: []byte{27, ']', '2', ';', '1', '2', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', 27, '\\'},
 		},
 		{
 			Title:  "123",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', 27, '\\'},
 		},
 		{
 			Title:  "1234",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', 27, '\\'},
 		},
 		{
 			Title:  "12345",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', 27, '\\'},
 		},
 		{
 			Title:  "123456",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', 27, '\\'},
 		},
 		{
 			Title:  "1234567",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', 27, '\\'},
 		},
 		{
 			Title:  "12345678",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', '8', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', '8', 27, '\\'},
 		},
 		{
 			Title:  "123456789",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', 27, '\\'},
 		},
 		{
 			Title:  "1234567890",
-			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', '0', 'S', 'T'},
+			Format: []byte{27, ']', '2', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', '0', 27, '\\'},
 		},
 		// TODO: test unicode
 	}
@@ -93,43 +93,43 @@ func TestFormatIcon(t *testing.T) {
 		},
 		{
 			Title:  "1",
-			Format: []byte{27, ']', '1', ';', '1', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', 27, '\\'},
 		},
 		{
 			Title:  "12",
-			Format: []byte{27, ']', '1', ';', '1', '2', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', 27, '\\'},
 		},
 		{
 			Title:  "123",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', 27, '\\'},
 		},
 		{
 			Title:  "1234",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', 27, '\\'},
 		},
 		{
 			Title:  "12345",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', 27, '\\'},
 		},
 		{
 			Title:  "123456",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', 27, '\\'},
 		},
 		{
 			Title:  "1234567",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', 27, '\\'},
 		},
 		{
 			Title:  "12345678",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', '8', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', '8', 27, '\\'},
 		},
 		{
 			Title:  "123456789",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', 27, '\\'},
 		},
 		{
 			Title:  "1234567890",
-			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', '0', 'S', 'T'},
+			Format: []byte{27, ']', '1', ';', '1', '2', '3', '4', '5', '6', '7', '8', '9', '0', 27, '\\'},
 		},
 		// TODO: test unicode
 	}
